@@ -1,6 +1,6 @@
 package Proc::tored::Pool::Manager;
 # ABSTRACT: OO interface to creating a managed worker pool service
-$Proc::tored::Pool::Manager::VERSION = '0.01';
+$Proc::tored::Pool::Manager::VERSION = '0.02';
 
 use strict;
 use warnings;
@@ -14,7 +14,6 @@ use Time::HiRes 'sleep';
 use Parallel::ForkManager;
 use Proc::tored::Pool::Constants ':events';
 use Proc::tored::Pool::Types -types;
-use Proc::tored::Pool::Worker;
 
 extends 'Proc::tored::Manager';
 
@@ -103,7 +102,12 @@ sub _build_forkmgr {
 sub assign {
   my $self = shift;
   my $code = shift;
-  push @_, sub { Proc::tored::Pool::Worker->work($code) };
+
+  push @_, sub {
+    try   { [1, $code->(@_)] }
+    catch { [0, $_] };
+  };
+
   $self->forkmgr->wait_for_available_procs(1);
   $self->forkmgr->start_child(@_);
   $self->forkmgr->wait_children; # triggers pending callbacks w/o blocking
@@ -132,7 +136,7 @@ Proc::tored::Pool::Manager - OO interface to creating a managed worker pool serv
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
